import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/material.dart';
import 'package:flutter_custom_clippers/flutter_custom_clippers.dart';
import 'package:step_progress_indicator/step_progress_indicator.dart';
import 'package:url_launcher/url_launcher.dart';
import 'package:vgkprogaming/theme/vgk-shared-theme.dart';

class VgkCommonWidget {
  static vgkIconWithTextWidget(icon, iconColor, text, textColor) {
    return Row(
      mainAxisAlignment: MainAxisAlignment.start,
      crossAxisAlignment: CrossAxisAlignment.start,
      children: <Widget>[
        Icon(
          icon,
          color: iconColor,
        ),
        Padding(
          padding: EdgeInsets.only(top: 3, left: 3),
          child: Text(
            text,
            style: textColor,
          ),
        )
      ],
    );
  }

  static CircleAvatar vgkBuildAvatar({double radius = 80, String image}) {
    return CircleAvatar(
      radius: radius - 2,
      backgroundColor: Colors.transparent,
      // backgroundImage: AssetImage('assets/images/ic_launcher.png'),
      backgroundImage: AssetImage(image),
    );
  }

  static vgkLaunchURL(String url) async {
    if (await canLaunch(url)) {
      if (url == 'mailto:niralakam@gmail.com') {
        await launch(
          url,
          forceWebView: false,
        );
      } else {
        await launch(
          url,
          forceWebView: true,
        );
      }
    }
  }

  static vgkCommonApplicationPrivacyData(
      width, image, background, primaryColor) {
    List<Widget> listViews = <Widget>[];
    listViews.add(
      Stack(
        children: [
          ClipPath(
            clipper: OvalBottomBorderClipper(),
            child: Container(
              margin: const EdgeInsets.only(top: 30),
              height: 380,
              decoration: BoxDecoration(
                color: HexColor(primaryColor),
              ),
            ),
          ),
          ClipPath(
            clipper: OvalBottomBorderClipper(),
            child: Container(
              height: 380,
              decoration: BoxDecoration(
                image: DecorationImage(
                  image: AssetImage(background),
                ),
              ),
              foregroundDecoration: BoxDecoration(
                color: HexColor(primaryColor).withOpacity(0.5),
              ),
            ),
          ),
          Center(
            child: Column(
              mainAxisAlignment: MainAxisAlignment.center,
              crossAxisAlignment: CrossAxisAlignment.center,
              children: [
                const SizedBox(height: 90),
                VgkCommonWidget.vgkBuildAvatar(
                  radius: width,
                  image: image,
                ),
                // const SizedBox(height: 10.0),
                // Column(
                //   crossAxisAlignment: CrossAxisAlignment.center,
                //   children: [
                //     RichText(
                //       text: TextSpan(
                //         text: 'P',
                //         style: VgkProGamingTheme.h3White,
                //         children: [
                //           TextSpan(
                //             text: 'UB',
                //             style: AppTheme.textStyleTripleExtraLargeBlack,
                //           ),
                //           TextSpan(
                //             text: 'G',
                //             style: AppTheme.textStyleTripleExtraLargeWhite,
                //           ),
                //           TextSpan(
                //             text: ' MOBILE Guidance',
                //             style: AppTheme.textStyleTripleExtraLargeWhite,
                //           ),
                //         ],
                //       ),
                //     ),
                //     Align(
                //       alignment: Alignment.center,
                //       child: Container(
                //         padding: new EdgeInsets.only(right: 20),
                //         child: RichText(
                //           textAlign: TextAlign.center,
                //           text: TextSpan(
                //             text: Constant.version,
                //             style: TextStyle(
                //               fontSize: 7,
                //               fontWeight: FontWeight.w700,
                //               color: AppTheme.white,
                //             ),
                //           ),
                //         ),
                //       ),
                //     ),
                //   ],
                // )
              ],
            ),
          ),
        ],
      ),
    );
    listViews.add(
      SizedBox(
        height: 16,
      ),
    );
    return listViews;
  }

  static vgkRangeInfo(name, value, precentage, primaryColor) {
    return Column(
      mainAxisAlignment: MainAxisAlignment.center,
      crossAxisAlignment: CrossAxisAlignment.start,
      children: <Widget>[
        Row(children: <Widget>[
          Expanded(
            child: Text(
              name,
              textAlign: TextAlign.left,
              style: VgkProGamingTheme.h3(primaryColor),
            ),
          ),
          Padding(
            padding: const EdgeInsets.only(left: 8),
            child: Text(
              value,
              textAlign: TextAlign.left,
              style: VgkProGamingTheme.h3(primaryColor),
            ),
          )
        ]),
        Padding(
          padding: const EdgeInsets.only(top: 4),
          child: StepProgressIndicator(
            totalSteps: 100,
            currentStep: precentage,
            size: 8,
            padding: 0,
            selectedColor: Colors.yellow,
            unselectedColor: Colors.cyan,
            roundedEdges: Radius.circular(10),
            selectedGradientColor: LinearGradient(
              begin: Alignment.topLeft,
              end: Alignment.bottomRight,
              colors: [HexColor('#00b4ab'), HexColor('#00b4ab')],
            ),
            unselectedGradientColor: LinearGradient(
              begin: Alignment.topLeft,
              end: Alignment.bottomRight,
              colors: [
                HexColor('#00b4ab').withOpacity(0.2),
                HexColor('#00b4ab').withOpacity(0.2)
              ],
            ),
          ),
        ),
      ],
    );
  }

  static Widget vgkContent(String value, TextStyle style) {
    return Container(
      child: Row(
        children: <Widget>[
          Expanded(
            child: Container(
              child: Padding(
                padding: const EdgeInsets.only(
                  left: VgkProGamingTheme.paddingDoubleExtraLarge,
                  right: VgkProGamingTheme.paddingDoubleExtraLarge,
                  bottom: VgkProGamingTheme.paddingSmall,
                ),
                child: Row(
                  children: <Widget>[
                    Expanded(
                      child: Text(
                        value,
                        textAlign: TextAlign.left,
                        style: style,
                      ),
                    ),
                  ],
                ),
              ),
            ),
          ),
        ],
      ),
    );
  }

  static Widget vgkCustomImage(String value) {
    return Container(
      padding: VgkProGamingTheme.edgeInsetsPaddingDoubleExtraLarge,
      child: ClipRRect(
        borderRadius: const BorderRadius.all(Radius.circular(16.0)),
        child: Stack(
          children: <Widget>[
            Column(
              children: <Widget>[
                AspectRatio(
                  aspectRatio: 2,
                  child: CachedNetworkImage(
                    imageUrl: value,
                    fit: BoxFit.fill,
                    progressIndicatorBuilder:
                        (context, url, downloadProgress) =>
                            CircularProgressIndicator(
                                value: downloadProgress.progress),
                    errorWidget: (context, url, error) => Icon(Icons.error),
                  ),
                ),
              ],
            )
          ],
        ),
      ),
    );
  }

  static Widget vgkParagraph(String value, TextStyle style, primaryColor) {
    return Padding(
      padding: EdgeInsets.only(
        right: VgkProGamingTheme.paddingDoubleExtraLarge,
        left: VgkProGamingTheme.paddingDoubleExtraLarge,
      ),
      child: Container(
        decoration: VgkProGamingTheme.decoration,
        child: Padding(
          padding: VgkProGamingTheme.edgeInsetsPaddingDoubleExtraLarge,
          child: Row(
            children: <Widget>[
              Expanded(
                child: Column(
                  mainAxisAlignment: MainAxisAlignment.start,
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: <Widget>[
                    Text(
                      value,
                      style: VgkProGamingTheme.h3(primaryColor),
                    ),
                  ],
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
