import 'package:flutter/material.dart';
import 'package:vgkprogaming/model/vgk-map-detail.dart';
import 'package:vgkprogaming/theme/vgk-shared-theme.dart';
import 'package:vgkprogaming/widget/vgk-sub-title-widget/vgk-sub-title-widget-with-animation.dart';

class VgkMapInfoWidget extends StatelessWidget {
  final AnimationController animationController;
  final Animation animation;
  final List<VgkMapDetail> mapDetails;
  final String primaryColor;
  const VgkMapInfoWidget({
    Key key,
    this.animationController,
    this.animation,
    this.mapDetails,
    this.primaryColor,
  }) : super(key: key);
  @override
  Widget build(BuildContext context) {
    return AnimatedBuilder(
      animation: animationController,
      builder: (BuildContext context, Widget child) {
        return FadeTransition(
          opacity: animation,
          child: new Transform(
            transform: VgkProGamingTheme.transform(animation),
            child: Padding(
              padding: VgkProGamingTheme.edgeInsetsPaddingDoubleExtraLarge,
              child: Container(
                decoration: BoxDecoration(
                  color: VgkProGamingTheme.boxBackground.withOpacity(0.6),
                  borderRadius: const BorderRadius.all(Radius.circular(16.0)),
                ),
                child: Padding(
                  padding: VgkProGamingTheme.edgeInsetsPaddingDoubleExtraLarge,
                  child: Row(
                    children: <Widget>[
                      Expanded(
                        child: Column(
                          mainAxisAlignment: MainAxisAlignment.start,
                          crossAxisAlignment: CrossAxisAlignment.start,
                          children: loadMapInfo(mapDetails, primaryColor),
                        ),
                      ),
                    ],
                  ),
                ),
              ),
            ),
          ),
        );
      },
    );
  }

  loadMapInfo(List<VgkMapDetail> mapDetails, primaryColor) {
    var result = <Widget>[];
    if (mapDetails != null && mapDetails.length > 0) {
      mapDetails.forEach((element) {
        result.add(VgkSubTitleWithAnimationWidget(
          titleTxt: element.title,
          animation: VgkProGamingTheme.animationOption(animationController),
          animationController: animationController,
          titlefontSize: VgkProGamingTheme.h1(primaryColor),
        ));
        result.add(VgkProGamingTheme.sizedBoxEmpty);
        if (element.contents != null && element.contents.length > 0) {
          int index = (element.contents.length ~/ 2).toInt();
          if (element.contents.length == 1) {
            index = 1;
          }
          int currentData = 0;
          for (var i = 0; i < index; i++) {
            var firstElement = element.contents[currentData];
            var secondElement;
            if (currentData + 1 < element.contents.length) {
              secondElement = element.contents[currentData + 1];
            }
            currentData = currentData + 2;
            result.add(
              widgetForDamageDetails(
                firstElement.key,
                firstElement.value,
                secondElement != null ? secondElement.key : "",
                secondElement != null ? secondElement.value : "",
              ),
            );
          }
        }
      });
    }
    return result;
  }
}

Widget widgetForDamageDetails(
    firstColumnTitle, firstColumnValue, secondColumnTitle, secondColumnValue) {
  return Padding(
    padding: const EdgeInsets.only(
      left: VgkProGamingTheme.paddingDoubleExtraLarge,
      right: VgkProGamingTheme.paddingDoubleExtraLarge,
      top: VgkProGamingTheme.paddingDoubleExtraSmall,
      bottom: VgkProGamingTheme.paddingDoubleExtraSmall,
    ),
    child: Row(
      children: <Widget>[
        Expanded(
          child: Row(
            mainAxisAlignment: MainAxisAlignment.start,
            crossAxisAlignment: CrossAxisAlignment.start,
            children: <Widget>[
              Column(
                mainAxisAlignment: MainAxisAlignment.start,
                crossAxisAlignment: CrossAxisAlignment.start,
                children: <Widget>[
                  Text(
                    firstColumnTitle,
                    textAlign: TextAlign.center,
                    style: VgkProGamingTheme.h2Gray,
                  ),
                  Padding(
                    padding: const EdgeInsets.only(top: 6),
                    child: Text(
                      firstColumnValue,
                      textAlign: TextAlign.center,
                      style: VgkProGamingTheme.h3Gray,
                    ),
                  ),
                ],
              ),
            ],
          ),
        ),
        Expanded(
          child: Row(
            mainAxisAlignment: MainAxisAlignment.start,
            crossAxisAlignment: CrossAxisAlignment.start,
            children: <Widget>[
              Column(
                mainAxisAlignment: MainAxisAlignment.start,
                crossAxisAlignment: CrossAxisAlignment.start,
                children: <Widget>[
                  Text(
                    secondColumnTitle,
                    textAlign: TextAlign.center,
                    style: VgkProGamingTheme.h2Gray,
                  ),
                  Padding(
                    padding: const EdgeInsets.only(top: 6),
                    child: Text(
                      secondColumnValue,
                      textAlign: TextAlign.center,
                      style: VgkProGamingTheme.h3Gray,
                    ),
                  ),
                ],
              ),
            ],
          ),
        )
      ],
    ),
  );
}
